from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Hardware(object):
    """
    Real-Time Monitoring - Hardware API
    
    Implements GET POST DEL PUT methods for Hardware endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getAlarms(self, deviceId):
        """
        Get hardware alarm list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/alarms?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEnvironments(self, deviceId):
        """
        Get hardware environment list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/environment?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getErrorAlarms(self):
        """
        Get hardware error list from device
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/errors"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInventory(self, deviceId):
        """
        Get hardware inventory list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/inventory?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatusSummary(self, deviceId):
        """
        Get hardware status summary from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/status/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncAlarms(self, deviceId):
        """
        Get hardware alarm list synchronously from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/synced/alarms?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncEnvironments(self, deviceId):
        """
        Get hardware environment list synchronously from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/synced/environment?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncInventory(self, deviceId):
        """
        Get hardware inventory list synchronously from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/synced/inventory?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSystem(self, deviceId):
        """
        Get hardware system data list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/system?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTempThreshold(self, deviceId):
        """
        Get hardware temperature list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/hardware/threshold?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Disaster(object):
    """
    Configuration - Disaster Recovery API
    
    Implements GET POST DEL PUT methods for Disaster Recovery endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def activate(self):
        """
        Activate cluster to start working as primary
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/activate"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getClusterInfo(self):
        """
        Get disaster recovery cluster info
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/clusterInfo"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def restoreConfigDb(self, payload):
        """
        Signal vManage to initiate configuration-db restore operation
        
        Parameters:
        payload:	Config-db meta payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/dbrestore"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getConfigDBRestoreStatus(self):
        """
        Config-db restore status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/dbrestorestatus"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deleteLocalDC(self):
        """
        Delete local data center
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/deleteLocalDataCenter"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def deleteDC(self):
        """
        Delete data center
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/deleteRemoteDataCenter"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def delete(self):
        """
        Delete disaster recovery
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/deregister"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getDetails(self):
        """
        Get disaster recovery details
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/details"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def download(self, token):
        """
        Downloading stats file
        
        Parameters:
        token	 (string):	Token
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/download/backup/{token}/db_bkp.tar.gz"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def downloadReplicationData(self, token, fileName):
        """
        Download replication data
        
        Parameters:
        token	 (string):	Token
		fileName	 (string):	File name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/download/{token}/{fileName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDRStatus(self):
        """
        Disaster recovery status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/drstatus"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getHistory(self):
        """
        Get disaster recovery switchover history
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/history"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLocalHistory(self):
        """
        Get disaster recovery local switchover history
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/localLatestHistory"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLocalDCState(self):
        """
        Get local data center details
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/localdc"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def pauseDR(self):
        """
        Pause DR
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/pause"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def pauseLocalArbitrator(self):
        """
        Pause DR for Local Arbitrator
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/pauseLocalArbitrator"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def pauseLocalDCForDR(self):
        """
        Pause DR for Local datacenter
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/pauseLocalDC"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def pauseLocalDCReplication(self):
        """
        Pause DR replication for Local datacenter
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/pauseLocalReplication"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def DRPauseReplication(self):
        """
        Pause DR data replication
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/pausereplication"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def update(self, request):
        """
        Update data centers for disaster recovery
        
        Parameters:
        request:	Datacenter registration request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/register"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, request)
        return response


    def register(self, request):
        """
        Register data centers for disaster recovery
        
        Parameters:
        request:	Datacenter registration request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/register"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def getRemoteDCMembersState(self):
        """
        Gets remote data center member state
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/remoteDcState"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRemoteDataCenterState(self):
        """
        Get remote data center details
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/remotedc"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateDRState(self, dcReg):
        """
        Update complete disaster recovery information to remote data center
        
        Parameters:
        dcReg:	Datacenter registration
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/remotedc"
        response = self.client.apiCall(HttpMethods.POST, endpoint, dcReg)
        return response


    def getRemoteDCVersion(self):
        """
        Get remote data center vManage version
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/remotedc/swversion"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def DRReplicationRequest(self, drrequest):
        """
        Replication Request message sent from primary
        
        Parameters:
        drrequest:	DR request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/requestimport"
        response = self.client.apiCall(HttpMethods.POST, endpoint, drrequest)
        return response


    def restartDC(self, dcReg):
        """
        Restart data center
        
        Parameters:
        dcReg:	Datacenter registration
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/restartDataCenter"
        response = self.client.apiCall(HttpMethods.POST, endpoint, dcReg)
        return response


    def getDRLocalReplicationSchedule(self):
        """
        Get disaster recovery local replication schedule
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/schedule"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getdrStatus(self):
        """
        Get disaster recovery status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def unpauseDR(self):
        """
        Unpause DR
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/unpause"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def unpauseLocalArbitrator(self):
        """
        Unpause DR for Local Arbitrator
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/unpauseLocalArbitrator"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def unpauseLocalDCForDR(self):
        """
        Unpause DR for Local datacenter
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/unpauseLocalDC"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def unpauseLocalDCReplication(self):
        """
        Unpause DR replication for local datacenter
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/unpauseLocalReplication"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def DRUnPauseReplication(self):
        """
        Un-Pause DR data replication
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/unpausereplication"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def updateDrState(self):
        """
        Update arbitrator with primary and secondary states cluster
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/updateDRConfigOnArbitrator"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def updateReplication(self, replicationstatus):
        """
        Update DR replication status
        
        Parameters:
        replicationstatus:	Replication status
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/updateReplication"
        response = self.client.apiCall(HttpMethods.POST, endpoint, replicationstatus)
        return response


    def getReachabilityInfo(self, nodelist):
        """
        Validate a list of nodes
        
        Parameters:
        nodelist:	Node list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/disasterrecovery/validateNodes"
        response = self.client.apiCall(HttpMethods.POST, endpoint, nodelist)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class FeatureCert(object):
    """
    Configuration - Feature Certificate API
    
    Implements GET POST DEL PUT methods for Feature Certificate endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getDeviceCert(self, deviceId):
        """
        Get feature cert from cEdge device        
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/featurecertificate/certificate?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def install(self, certRequest):
        """
        Upload feature cert for cEdge device        
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        certRequest:	Install feature cert request for cEdge
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/featurecertificate/certificate"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, certRequest)
        return response


    def getDeviceCsr(self, deviceId):
        """
        Get CSR from cEdge device        
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/featurecertificate/devicecsr?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def genDeviceCsr(self, csrRequest):
        """
        Create CSR for cEdge device        
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        csrRequest:	CSR request for cEdge
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/featurecertificate/devicecsr"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, csrRequest)
        return response


    def revoke(self, revokeReq):
        """
        Revoke feature cert from cEdge device        
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        revokeReq:	Revoking feature cert request for cEdge
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/featurecertificate/revoke"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, revokeReq)
        return response


    def getFeatureCaState(self):
        """
        Get Feature CA state        
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/featurecertificate/syslogconfig"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Software(object):
    """
    Configuration - Device Software Update API
    
    Implements GET POST DEL PUT methods for DeviceSoftwareUpdate endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def installPkg(self):
        """
        Install software package
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getUploadImagesCount(self, imageType):
        """
        Number of software image presented in vManage repository
        
        Parameters:
        imageType	 (array):	Image type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/imageCount?imageType={imageType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def downloadPkgFile(self, fileName, imageType):
        """
        Download software package file
        
        Parameters:
        fileName	 (string):	Pakcage file name
		imageType	 (string):	Image type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/{fileName}?imageType={imageType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processSoftwareImage(self, imageType):
        """
        Install software image package
        
        Parameters:
        imageType	 (string):	Image type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/{imageType}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getImgMeta(self, versionId):
        """
        Update Package Metadata
        
        Parameters:
        versionId	 (string):	Image ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/{versionId}/metadata"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editImgMeta(self, imageData, versionId):
        """
        Update Package Metadata
        
        Parameters:
        imageData:	Image Meta Data
		versionId	 (string):	Image ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/{versionId}/metadata"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, imageData)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class IP(object):
    """
    Real-Time Monitoring - IP API
    
    Implements GET POST DEL PUT methods for IP endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getFib(self, vpnId, af, prefix, tloc, color, deviceId):
        """
        Get FIB list from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		af	 (string):	Address family
		prefix	 (string):	IP prefix
		tloc	 (string):	tloc IP
		color	 (string):	tloc color
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/fib?vpnId={vpnId}&af={af}&prefix={prefix}&tloc={tloc}&color={color}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIetfRouting(self, instanceName, af, outIf, srcProto, nextHop, deviceId):
        """
        Get ietf routing list from device
        
        Parameters:
        instanceName	 (string):	VPN Id
		af	 (string):	Address family
		outIf	 (string):	Outgoing Interface
		srcProto	 (string):	Source Protocol
		nextHop	 (string):	Next Hop Address
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/ipRoutes?instanceName={instanceName}&af={af}&outIf={outIf}&srcProto={srcProto}&nextHop={nextHop}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIPMfibOil(self, deviceId):
        """
        Get IP MFIB OIL list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/mfiboil?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIPMfibStats(self, deviceId):
        """
        Get IP MFIB statistics list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/mfibstats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIPMfibSummary(self, deviceId):
        """
        Get IP MFIB summary list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/mfibsummary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNatFilter(self, natVpnId, natIfname, privateSrcAddr, proto, deviceId):
        """
        Get NAT filter list from device
        
        Parameters:
        natVpnId	 (string):	NAT VPN Id
		natIfname	 (string):	NAT interface name
		privateSrcAddr	 (string):	Private source address
		proto	 (string):	Protocol
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/nat/filter?natVpnId={natVpnId}&natIfname={natIfname}&privateSrcAddr={privateSrcAddr}&proto={proto}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNatInterface(self, deviceId):
        """
        Get NAT interface list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/nat/interface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNatIfStats(self, deviceId):
        """
        Get NAT interface statistics list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/nat/interfacestatistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNatTranslations(self, deviceId):
        """
        Get NAT translation list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/nat/translation?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNat64Translations(self, deviceId):
        """
        Get NAT64 interface list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/nat64/translation?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRouteTable(self, vpnId, af, prefix, protocol, deviceId):
        """
        Get route table list from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		af	 (string):	Address family
		prefix	 (string):	IP prefix
		protocol	 (string):	IP protocol
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ip/routetable?vpnId={vpnId}&af={af}&prefix={prefix}&protocol={protocol}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Workflow(object):
    """
    Workflow - Management API
    
    Implements GET POST DEL PUT methods for Management endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getWorkflows(self, type, id):
        """
        List all workflows for the given tenant
        
        Parameters:
        type	 (string):	Workflow type
		id	 (string):	Workflow id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/workflow?type={type}&id={id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def saveWorkflow(self, payload):
        """
        Saves the workflow
        
        Parameters:
        payload:	Request to save already created workflow with given user context
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/workflow"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, payload)
        return response


    def createWorkflow(self, payload):
        """
        Creates a workflow in the system
        
        Parameters:
        payload:	Request to create workflow with given user context
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/workflow"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def deleteWorkflow(self, payload, id):
        """
        Deletes the workflow
        
        Parameters:
        payload:	Request to delete the workflow
		id	 (string):	Workflow id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/workflow?id={id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, payload)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Vmanage(object):
    """
    Certificate Management - vManage API
    
    Implements GET POST DEL PUT methods for vManage endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def showInfo(self):
        """
        Retrieves Certificate Signing Request information
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/setting/configuration/webserver/certificate"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def importCert(self, signedCert):
        """
        Import a signed web server certificate
        
        Parameters:
        signedCert:	Singed certificate
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/setting/configuration/webserver/certificate"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, signedCert)
        return response


    def getCSR(self, csrRequest):
        """
        Generate Certificate Signing Request
        
        Parameters:
        csrRequest:	CSR signing request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/setting/configuration/webserver/certificate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, csrRequest)
        return response


    def dumpCert(self, type):
        """
        Get certificate with alias name
        
        Parameters:
        type	 (string):	Key alias
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/setting/configuration/webserver/certificate/certificate?type={type}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCert(self):
        """
        Get certificate for alias server
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/setting/configuration/webserver/certificate/getcertificate"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def rollback(self, type):
        """
        Rollback certificate with alias name
        
        Parameters:
        type	 (string):	Key alias
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/setting/configuration/webserver/certificate/rollback?type={type}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Circuits(object):
    """
    Configuration - Circuits API
    
    Implements GET POST DEL PUT methods for Circuits endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def get(self):
        """
        Get network circuits
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/circuit"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def create(self, networkcircuit):
        """
        Create network circuits
        
        Parameters:
        networkcircuit:	Network circuit
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/circuit"
        response = self.client.apiCall(HttpMethods.POST, endpoint, networkcircuit)
        return response


    def edit(self, networkcircuit, id):
        """
        Edit network circuits
        
        Parameters:
        networkcircuit:	Network circuit
		id	 (string):	Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/circuit/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, networkcircuit)
        return response


    def delete(self, id):
        """
        Delete network circuits
        
        Parameters:
        id	 (string):	Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/circuit/{id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Agent(object):
    """
    Data Collection Agent API
    
    Implements GET POST DEL PUT methods for DataCollectionAgent endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def createStats(self, statsquery):
        """
        Get statistics data
        
        Parameters:
        statsquery:	Stats query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/analytics"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, statsquery)
        return response


    def getAllStatsDataDCA(self, statssetting):
        """
        Get all statistics setting data
        
        Parameters:
        statssetting:	Stats setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/analytics/all"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statssetting)
        return response


    def getAccessToken(self):
        """
        Get DCA access token
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/accesstoken"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def storeAccessToken(self, dcaaccesstoken):
        """
        Set DCA access token
        
        Parameters:
        dcaaccesstoken:	DCA access token
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/accesstoken"
        response = self.client.apiCall(HttpMethods.POST, endpoint, dcaaccesstoken)
        return response


    def generateAlarm(self, msg):
        """
        Generate DCA alarms
        
        Parameters:
        msg:	DCA alarm message
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/alarm"
        response = self.client.apiCall(HttpMethods.POST, endpoint, msg)
        return response


    def getIdToken(self):
        """
        Get DCA Id token
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/idtoken"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def storeIdToken(self, token):
        """
        Set DCA Id token
        
        Parameters:
        token:	DCA Id token
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/idtoken"
        response = self.client.apiCall(HttpMethods.POST, endpoint, token)
        return response


    def getTelemetrySettings(self):
        """
        Get DCA telemetry settings
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/telemetry"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateDCADeviceStateData(self, query, state_data_type):
        """
        Get device state data
        
        Parameters:
        query:	Query string
		state_data_type	 (string):	Device state data
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/data/device/state/{state_data_type}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def generateDCADeviceStatisticsData(self, query, dataType):
        """
        Get device statistics data
        
        Parameters:
        query:	Query string
		dataType	 (string):	Device statistics data
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/data/device/statistics/{dataType}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getDCATenantOwners(self):
        """
        Get DCA tenant owners
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/dcatenantowners"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listAllDevicesDCA(self, query):
        """
        Get all devices
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/device"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getCrashLogs(self, query):
        """
        Get crash log
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/device/crashlog/details"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getCrashLogsSynced(self, deviceId):
        """
        Get device crash log
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/device/crashlog/synced?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudServicesConfigurationDCA(self):
        """
        Get DCA cloud service configuration
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/settings/configuration/cloudservices/dca"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createDCAAnalyticsDataFile(self, query, type):
        """
        Create analytics config data
        
        Parameters:
        query:	Query string
		type	 (string):	Data type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/settings/configuration/{type}/dca"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatsDBIndexStatus(self, statssetting):
        """
        Get statistics setting status
        
        Parameters:
        statssetting:	Stats setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/statistics/settings/status"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statssetting)
        return response


    def getDevicesDetailsDCA(self, query):
        """
        Get device details
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/system/device"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getDCAAttachedConfigToDevice(self, query):
        """
        Get attached config to device
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/template/device/config/attachedconfig"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getTemplatePolicyDefinitionsDCA(self, query):
        """
        Get template policy definitions
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/template/policy/definition/approute"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getVPNListsDCA(self, query):
        """
        Get VPN details
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/template/policy/list/vpn"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getVedgeTemplateListDCA(self, query):
        """
        Get vEdge template list
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/template/policy/vedge"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getVsmartTemplateListDCA(self, query):
        """
        Get vSmart template list
        
        Parameters:
        query:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/template/policy/vsmart"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Cellular(object):
    """
    Real-Time Monitoring - Cellular API
    
    Implements GET POST DEL PUT methods for Cellular endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getConnections(self, deviceId):
        """
        Get cellular connection list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/connection?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getHardwareList(self, deviceId):
        """
        Get cellular hardware list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/hardware?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getModemList(self, policyId):
        """
        Get cellular modem list from device
        
        Parameters:
        policyId	 (string):	Policy IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/modem?policyId={policyId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNetworkList(self, deviceId):
        """
        Get cellular network list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/network?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getProfileList(self, deviceId):
        """
        Get cellular profile list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/profiles?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRadioList(self, deviceId):
        """
        Get cellular radio list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/radio?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSessionsList(self, ifName, priDns, deviceId):
        """
        Get cellular session list from device
        
        Parameters:
        ifName	 (string):	Interface name
		priDns	 (string):	DNS primary IP
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/sessions?ifName={ifName}&priDns={priDns}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCellularStatusList(self, deviceId):
        """
        Get cellular status list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cellular/status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Policy(object):
    """
    MDP - Internal Policy Management API
    
    Implements GET POST DEL PUT methods for Internal Policy Management endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def add(self, policy):
        """
        Add internal policy from vmanage
        
        Parameters:
        policy:	    Internal Policy
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/policies/mdpconfig"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policy)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Master(object):
    """
    Configuration - Template Master API
    
    Implements GET POST DEL PUT methods for TemplateMaster endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getMasterTemplateList(self, feature):
        """
        Generate template list
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        feature	 (string):	Feature
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device?feature={feature}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createCLITemplate(self, createtemplaterequest):
        """
        Create CLI template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        createtemplaterequest:	Create template request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/cli"
        response = self.client.apiCall(HttpMethods.POST, endpoint, createtemplaterequest)
        return response


    def createMasterTemplate(self, request):
        """
        Create a device template from feature templates and sub templates
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        request:	Create template request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/feature"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def isMigrationRequired(self):
        """
        Check if any device templates need migration
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/is_migration_required"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTemplateForMigration(self, hasAAA):
        """
        Generate a list of templates which require migration
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        hasAAA	 (boolean):	Return only those uses AAA
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/migration?hasAAA={hasAAA}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def migrateTemplates(self, id, prefix, includeAll):
        """
        Migrate the device templates given the template Ids
        
        Parameters:
        id	 (array):	Template Id
		prefix	 (string):	Prefix
		includeAll	 (boolean):	Include all flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/migration?id={id}&prefix={prefix}&includeAll={includeAll}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def migrationInfo(self):
        """
        Returns the mapping between old and migrated templates
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/migration_info"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMasterTemplateDefinition(self, templateId):
        """
        Generate template by Id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/object/{templateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def changeTemplateResourceGroup(self, templateId, resourceGroupName):
        """
        Change template resource group
        
        Parameters:
        templateId	 (string):	Template Id
		resourceGroupName	 (string):	Resource group name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/resource-group/{resourceGroupName}/{templateId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getOutOfSyncTemplates(self):
        """
        Get template sync status
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/syncstatus"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getOutOfSyncDevices(self, templateId):
        """
        Get out of sync devices
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/syncstatus/{templateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editMasterTemplate(self, template, templateId):
        """
        Edit template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        template:	Template
		templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/{templateId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, template)
        return response


    def deleteMasterTemplate(self, templateId):
        """
        Delete template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/{templateId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from requests import Session
import json
import urllib3

class Vmanage(object):
    
    def __init__(self, host, port, username, password):
        self.host = host
        self.port = port
        self.username = username
        self.password = password
        self.session = Session()
        self.session.headers['Content-Type'] = 'application/x-www-form-urlencoded'
        self.session.verify = False
        urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
        
        #login
        self.login_url = f"https://{host}:{port}/j_security_check"
        login_data = {
            "j_username":self.username,
            "j_password":self.password
        }
        self.session.post(url=self.login_url, data=login_data)

        #get token
        response = self.session.get(url=f"https://{host}:{port}/dataservice/client/token")
        token = response.text

        # configure headers for further use
        self.session.headers['Content-Type'] = 'application/json'
        self.session.headers['X-XSRF-TOKEN'] = token
        


from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Logging(object):
    """
    Utility - Logging API
    
    Implements GET POST DEL PUT methods for Logging endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def listLogFileDetails(self):
        """
        Lists content of log file. This API accepts content type as text/plain. It is mandatory to provide response content type.  Any other content type would result in empty response.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/util/logfile/appserver"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listVManageServerLogLastNLines(self, lines):
        """
        List last N lines of log file. This API accepts content type as text/plain. It is mandatory to provide response content type.  Any other content type would result in empty response.
        
        Parameters:
        lines	 (integer):	Number of lines
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/util/logfile/appserver/lastnlines?lines={lines}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def debugLog(self, payload):
        """
        Test whether logging works
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/util/logging/debuglog"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def setLogLevel(self, payload):
        """
        Set log level for logger
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/util/logging/level"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def listLoggers(self):
        """
        List loggers
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/util/logging/loggers"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class SFP(object):
    """
    Real-Time Monitoring - SFP API
    
    Implements GET POST DEL PUT methods for SFP endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getDetail(self, ifname, deviceId):
        """
        Get SFP detail
        
        Parameters:
        ifname	 (string):	IF Name
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/sfp/detail?ifname={ifname}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDiag(self, ifname, deviceId):
        """
        Get SFP diagnostic
        
        Parameters:
        ifname	 (string):	IF Name
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/sfp/diagnostic?ifname={ifname}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDiagAlarm(self, ifname, deviceId):
        """
        Get SFP diagnostic measurement alarm
        
        Parameters:
        ifname	 (string):	IF Name
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/sfp/diagnosticMeasurementAlarm?ifname={ifname}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDiagValue(self, ifname, deviceId):
        """
        Get SFP diagnostic measurement value
        
        Parameters:
        ifname	 (string):	IF Name
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/sfp/diagnosticMeasurementValue?ifname={ifname}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Backup(object):
    """
    Scheduled Backup Restore API
    
    Implements GET POST DEL PUT methods for ScheduledBackupRestore endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def deleteSchduledBackup(self, taskId, backupInfoId):
        """
        Delete all or a specific backup file stored in vManage
        
        Parameters:
        taskId	 (string):	task id
		backupInfoId	 (string):	Local Backup Info Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/backup/backupinfo?taskId={taskId}&backupInfoId={backupInfoId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getLocalBackupInfo(self, localBackupInfoId):
        """
        Get a localBackupInfo record by localBackupInfoId
        
        Parameters:
        localBackupInfoId	 (string):	localBackupInfo Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/backup/backupinfo/{localBackupInfoId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def downloadBackupFile(self, path):
        """
        Download a Backup File that is already stored in vManage
        
        Parameters:
        path	 (string):	File path
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/backup/download/{path}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def exportBackup(self, request):
        """
        Trigger a backup of configuration database and statstics database and store it in vManage
        
        Parameters:
        request:	backup request information
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/backup/export"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def listBackup(self, size):
        """
        List all backup files of a tenant stored in vManage
        
        Parameters:
        size	 (string):	size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/backup/list?size={size}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def importScheduledBackup(self):
        """
        Submit a previously backed up file and import the data and apply it to the configuraion database
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/restore/import"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def remoteImportBackup(self, payload):
        """
        Remote import backup from a remote URL and import the data and apply it to the configuraion database
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/restore/remoteimport"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def scheduleBackup(self, requestInfo):
        """
        create  backup scheduler config-db and statstics database with startDateTime and persist to config-db
        
        Parameters:
        requestInfo:	schedule request information
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/schedule/create"
        response = self.client.apiCall(HttpMethods.POST, endpoint, requestInfo)
        return response


    def listSchedules(self, limit):
        """
        Get a schedule record for backup by scheduler id
        
        Parameters:
        limit	 (integer):	size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/schedule/list?limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getScheduleRecordForBackup(self, schedulerId):
        """
        Get a schedule record for backup by scheduler id
        
        Parameters:
        schedulerId	 (string):	scheduler id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/schedule/{schedulerId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deleteSchedule(self, schedulerId):
        """
        Delete a schedule record for backup in vManage by scheduler id
        
        Parameters:
        schedulerId	 (string):	scheduler id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/schedule/{schedulerId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Umbrella(object):
    """
    Real-Time Monitoring - Umbrella API
    
    Implements GET POST DEL PUT methods for Umbrella endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getUmbrellaDevReg(self, deviceId):
        """
        Get Umbrella device registration from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/umbrella/device-registration?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUmbrellaDNSCrypt(self, deviceId):
        """
        Get Umbrella DNScrypt information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/umbrella/dnscrypt?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUmbrellaDpStats(self, deviceId):
        """
        Get Umbrella dp-stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/umbrella/dp-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUmbrellaOverview(self, deviceId):
        """
        Get Umbrella overview from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/umbrella/overview?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUmbrellaConfig(self, deviceId):
        """
        Get Umbrella configuration from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/umbrella/umbrella-config?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Lock(object):
    """
    Configuration - Template Lock API
    
    Implements GET POST DEL PUT methods for TemplateLock endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def updateLeaseTime(self, processId):
        """
        Update lease
        
        Parameters:
        processId	 (string):	Process Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/lock/{processId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint)
        return response


    def removeLock(self, processId):
        """
        Remove lock
        
        Parameters:
        processId	 (string):	Process Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/lock/{processId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Policy(object):
    """
    MDP - Policy Management API
    
    Implements GET POST DEL PUT methods for Policy Management endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getPolicies(self, nmsId):
        """
        Retrieve MDP policies
        
        Parameters:
        nmsId:  NMS server ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/policies/{nmsId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updatePolicyStatus(self, policylist, nmsId):
        """
        update policy status
        
        Parameters:
        policylist:	policyList
		nmsId:  NMS server ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/policies/{nmsId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policylist)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class ACIPolicyBuilder(object):
    """
    Partner - ACI Policy Builder API
    
    Implements GET POST DEL PUT methods for ACI Policy Builder endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getACIDefinitions(self):
        """
        Get ACI definitions
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDscpMappings(self, partnerId):
        """
        Get DSCP policy
        
        Parameters:
        partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy/dscpmapping/{partnerId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createDscpMappings(self, acidefinition, partnerId):
        """
        Create an ACI definition entry
        
        Parameters:
        acidefinition:	ACI definition
		partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy/dscpmapping/{partnerId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, acidefinition)
        return response


    def deleteDscpMappings(self, partnerId):
        """
        Delete DSCP mapping
        
        Parameters:
        partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy/dscpmapping/{partnerId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getEvents(self, partnerId, starttime, endtime):
        """
        Get ACI events
        
        Parameters:
        partnerId	 (string):	Partner Id
		starttime	 (integer):	Start time
		endtime	 (integer):	End time
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy/events/{partnerId}?starttime={starttime}&endtime={endtime}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDataPrefixMappings(self, partnerId):
        """
        Get prefix mapping
        
        Parameters:
        partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy/prefixmapping/{partnerId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setDataPrefixMappings(self, prefixdefinition, partnerId):
        """
        Create data prefix mapping
        
        Parameters:
        prefixdefinition:	Prefix definition
		partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy/prefixmapping/{partnerId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, prefixdefinition)
        return response


    def getDataPrefixSequences(self):
        """
        Get data prefix sequence
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/aci/policy/sequences"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class AarStats(object):
    """
    Monitoring - Application-Aware Routing Statistics API
    
    Implements GET POST DEL PUT methods for AwareRoutingStatistics endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getHealthSummary(self, type, limit, query):
        """
        Get application-aware routing statistics summary from device
        
        Parameters:
        type	 (string):	Type
		limit	 (integer):	Query result size
		query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/transport/summary/{type}?limit={limit}&query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getHealth(self, type, query, limit):
        """
        Get application-aware routing statistics from device
        
        Parameters:
        type	 (string):	Type
		query    (string):  Query filter
		limit	 (string):	Query result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/transport/{type}?query={query}&limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class CrashLog(object):
    """
    Real-Time Monitoring - Crash Log API
    
    Implements GET POST DEL PUT methods for CrashLog endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getLogs(self, deviceId):
        """
        Get device crash logs from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/crashlog?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAllLogs(self):
        """
        Get device crash logs for all device
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/crashlog/details"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInfo(self, deviceId, filename):
        """
        Get device crash info from device
        
        Parameters:
        deviceId	 (string):	Device IP
		filename	 (string):	Crash file name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/crashlog/log?deviceId={deviceId}&filename={filename}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLogsSynced(self, deviceId):
        """
        Get device crash logs synchronously from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/crashlog/synced?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Vedge(object):
    """
    Configuration - vEdge Template Policy API
    
    Implements GET POST DEL PUT methods for vEdgeTemplatePolicy endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def generatePolicyTemplateList(self):
        """
        Get policy details
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createVEdgeTemplate(self, templatepolicy):
        """
        Create template
        
        Parameters:
        templatepolicy:	Template policy
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge"
        response = self.client.apiCall(HttpMethods.POST, endpoint, templatepolicy)
        return response


    def getVEdgeTemplate(self, policyId):
        """
        Get template
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge/definition/{policyId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVEdgePolicyDeviceList(self):
        """
        Get device list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge/devices"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceListByPolicy(self, policyId):
        """
        Get device list by policy
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge/devices/{policyId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editVEdgeTemplate(self, templatepolicy, policyId):
        """
        Edit template
        
        Parameters:
        templatepolicy:	Template policy
		policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge/{policyId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, templatepolicy)
        return response


    def deleteVEdgeTemplate(self, policyId):
        """
        Delete template
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge/{policyId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def changePolicyResourceGroup(self, policyId, resourceGroupName):
        """
        Change policy resource group
        
        Parameters:
        policyId	 (string):	Policy Id
		resourceGroupName	 (string):	Resrouce group name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vedge/{resourceGroupName}/{policyId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Control(object):
    """
    Real-Time Monitoring - Device Control API
    
    Implements GET POST DEL PUT methods for DeviceControl endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getAffinityConfig(self, deviceId):
        """
        Get affinity config from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/affinity/config?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAffinityStatus(self, deviceId):
        """
        Get affinity status from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/affinity/status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createRealTimeConnectionList(self, peerType, sysIp, deviceId):
        """
        Get connections list from device (Real Time)
        
        Parameters:
        peerType	    (string):	Peer type
		sysIp	        (string):	Peer system IP
		deviceId	    (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/connections?peerType={peerType}&sysIp={sysIp}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createConnectionHistoryListRealTime(self, peerType, sysIp, deviceId):
        """
        Get connections history list from device (Real Time)
        
        Parameters:
        peerType	 (string):	Peer type
		sysIp	 (string):	Peer system IP
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/connectionshistory?peerType={peerType}&sysIp={sysIp}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTotalCountForDeviceStates(self, isCached):
        """
        Get number of vedges and vsmart device in different control states
        
        Parameters:
        isCached	 (boolean):	Device State cached
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/count?isCached={isCached}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createLinkList(self, state):
        """
        Get connections list
        
        Parameters:
        state	 (string):	Device State
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/links?state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createLocalPropertiesListListRealTIme(self, deviceId):
        """
        Get local properties list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/localproperties?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def networkSummary(self, state):
        """
        Get list of unreachable devices
        
        Parameters:
        state	 (string):	Device State
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/networksummary?state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConnectionStatistics(self, deviceId):
        """
        Get connection statistics from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/statistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLocalDeviceStatus(self):
        """
        Get local device status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createConnectionsSummary(self, deviceId):
        """
        Get connections summary from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceControlStatusSummary(self, deviceId):
        """
        Get device control status summary
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/summary/device?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createSyncedConnectionList(self, peerType, sysIp, deviceId):
        """
        Get connections list from vManage
        
        Parameters:
        peerType	 (string):	Peer type
		sysIp	 (string):	Peer system IP
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/synced/connections?peerType={peerType}&sysIp={sysIp}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createLocalPropertiesSyncedList(self, deviceId):
        """
        Get local properties list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/synced/localproperties?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createWanInterfaceSyncedList(self, deviceId):
        """
        Get WAN interface list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/synced/waninterface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createValidDevicesListRealTime(self, deviceId):
        """
        Get valid device list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/validdevices?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getValidVManageIdRealTime(self, deviceId):
        """
        Get valid vManage from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/validvmanageid?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createValidVSmartsListRealTime(self, deviceId):
        """
        Get valid vSmart list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/validvsmarts?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createWanInterfaceListList(self, deviceId):
        """
        Get WAN interface list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/waninterface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPortHopColor(self, deviceId):
        """
        Get port hop colors
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/control/waninterface/color?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class AwareRoute(object):
    """
    Real-Time Monitoring - Application-Aware Route API
    
    Implements GET POST DEL PUT methods for AwareRoute endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getSlaList(self, deviceId):
        """
        Get SLA class list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-route/sla-class?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatList(self, remote_system_ip, local_color, remote_color, deviceId):
        """
        Get application-aware routing statistics from device (Real Time)
        
        Parameters:
        remote-system-ip	 (string):	Remote system IP
		local-color	 (string):	Local color
		remote-color	 (string):	Remote color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/app-route/statistics?remote-system-ip={remote_system_ip}&local-color={local_color}&remote-color={remote_color}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Downloader(object):
    """
    Monitoring - Stats Download API
    
    Implements GET POST DEL PUT methods for StatsDownload endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def fetchList(self, processType):
        """
        fetchList Description
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/download/{processType}/fetchvManageList"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def download(self, processType, fileType, queue, deviceIp, token, fileName):
        """
        Downloading stats file
        
        Parameters:
        processType	 (string):	Process type
		fileType	 (string):	File type
		queue	 (string):	Queue name
		deviceIp	 (string):	Device IP
		token	 (string):	Token
		fileName	 (string):	File name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/download/{processType}/file/{fileType}/{queue}/{deviceIp}/{token}/{fileName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def downloadList(self, bodyParameter, processType):
        """
        Downloading list of stats file
        
        Parameters:
        bodyParameter:	Description
		processType	 (string):	Possible types are: remoteprocessing, dr
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/download/{processType}/filelist"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Backup(object):
    """
    Tenant Backup Restore API
    
    Implements GET POST DEL PUT methods for Tenant Backup Restore endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def deleteBkp(self, fileName):
        """
        Delete all or a specific backup file stored in vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        fileName	 (string):	File name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantbackup/delete?fileName={fileName}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def downloadBkpFile(self, path):
        """
        Download a Backup File that is already stored in vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        path	 (string):	File path
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantbackup/download/{path}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def exportBkp(self):
        """
        Trigger a backup of configuration database and store it in vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantbackup/export"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def importBkp(self):
        """
        Submit a previously backed up file and import the data and apply it to the configuraion database
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantbackup/import"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def listBkp(self):
        """
        List all backup files of a tenant stored in vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantbackup/list"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Colo(object):
    """
    Monitoring - Colocation Cluster API
    
    Implements GET POST DEL PUT methods for ColocationCluster endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getDetailById(self, clusterId):
        """
        Provide details of ids of existing clusters
        
        Parameters:
        clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/cluster?clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConfigById(self, clusterId):
        """
        Provide details of devices of clusters
        
        Parameters:
        clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/cluster/config?clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPortMappingById(self, clusterId):
        """
        Provide details of port mappings in the cluster
        
        Parameters:
        clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/cluster/portView?clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceDetailById(self, deviceId):
        """
        List details for Device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/device?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSystemStatusById(self, deviceId):
        """
        List all connected VNF to a device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/device/system?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getvnfById(self, deviceId):
        """
        List all VNF attached with Device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/device/vnf?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listNetworkFunctionMap(self):
        """
        Retrieve network function listing
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/networkfunction/listmap"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getpnfDetails(self, clusterId):
        """
        List all PNF by cluster Id
        
        Parameters:
        clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/pnf?clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPNFConfig(self, pnfSerialNumber, clusterId):
        """
        List configuration of PNF
        
        Parameters:
        pnfSerialNumber	 (string):	PNF serial number
		clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/pnf/configuration?pnfSerialNumber={pnfSerialNumber}&clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getServiceChainDetails(self, clusterId, userGroupName):
        """
        List all service chain or service chains by Id
        
        Parameters:
        clusterId	 (string):	Cluster Id
		userGroupName	 (string):	UserGroup Name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/servicechain?clusterId={clusterId}&userGroupName={userGroupName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getServiceGroupById(self, clusterId):
        """
        List all attached serviceGroups to cluster
        
        Parameters:
        clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/servicegroup?clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getvnfDetails(self, clusterId, userGroupName):
        """
        Provide details of all existing VNF
        
        Parameters:
        clusterId	 (string):	Cluster Id
		userGroupName	 (string):	UserGroup Name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/vnf?clusterId={clusterId}&userGroupName={userGroupName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def vnfActions(self, vmName, deviceId, action):
        """
        VNF action
        
        Parameters:
        vmName	 (string):	VM Name
		deviceId	 (string):	Device Id
		action	 (string):	Action
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/vnf/action?vmName={vmName}&deviceId={deviceId}&action={action}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getVNFEventsCountDetail(self, user_group):
        """
        Get event detail of VNF
        
        Parameters:
        user_group	 (string):	user group name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/vnf/alarms?user_group={user_group}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVNFAlarmCount(self, user_group):
        """
        Get event detail of VNF
        
        Parameters:
        user_group	 (string):	user group name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/vnf/alarms/count?user_group={user_group}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVNFEventsDetail(self, vnfName):
        """
        Get event detail of VNF
        
        Parameters:
        vnfName	 (string):	VNF name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/vnf/events?vnfName={vnfName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVNFInterfaceDetail(self, vnfName, deviceIp, deviceClass):
        """
        Get interface detail of VNF
        
        Parameters:
        vnfName	 (string):	VNF name
		deviceIp	 (string):	Device IP
		deviceClass	 (string):	Device class
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/monitor/vnf/interface?vnfName={vnfName}&deviceIp={deviceIp}&deviceClass={deviceClass}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class CustomApp(object):
    """
    Configuration - Policy Custom Application Builder API
    
    Implements GET POST DEL PUT methods for PolicyCustomApplicationBuilder endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def MapTrafficProfiles(self, apppayload):
        """
        Set SLA class for policy cloud discovered applications
        
        Parameters:
        apppayload:	App payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/clouddiscoveredapp"
        response = self.client.apiCall(HttpMethods.POST, endpoint, apppayload)
        return response


    def getCustomApps(self):
        """
        Get all policy custom applications
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/customapp"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def create(self, apppayload):
        """
        Create a policy custom applications
        
        Parameters:
        apppayload:	App payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/customapp"
        response = self.client.apiCall(HttpMethods.POST, endpoint, apppayload)
        return response


    def getById(self, id):
        """
        Get a policy custom applications
        
        Parameters:
        id	 (string):	Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/customapp/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def edit(self, apppayload, id):
        """
        Edit a policy custom applications
        
        Parameters:
        apppayload:	App payload
		id	 (string):	Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/customapp/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, apppayload)
        return response


    def delete(self, id):
        """
        Delete a policy custom applications
        
        Parameters:
        id	 (string):	Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/customapp/{id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Appqoe(object):
    """
    Real-Time Monitoring - Appqoe API
    
    Implements GET POST DEL PUT methods for Appqoe endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getHputStats(self, deviceId):
        """
        Get Appqoe Hput Statistics from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/appqoe-hput-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNatStats(self, deviceId):
        """
        Get Appqoe Nat Statistics from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/appqoe-nat-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRmResources(self, deviceId):
        """
        Get Appqoe Resource Manager resources from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/appqoe-rm-resource?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRMStats(self, deviceId):
        """
        Get Appqoe RM Statistics from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/appqoe-rm-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getServicesStatus(self, deviceId):
        """
        Get Appqoe Services Status from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/appqoe-services-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSppiPipeStats(self, deviceId):
        """
        Get Appqoe Sppi Pipe Stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/appqoe-sppi-pipe-resource?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSppiQueueStats(self, deviceId):
        """
        Get Appqoe Sppi Queue Stats from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/appqoe-sppi-queue-resource?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getClusterSummary(self, deviceId):
        """
        Get Appqoe Cluster Summary from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/cluster-summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getErrorRecent(self, deviceId):
        """
        Get Appqoe error recent from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/error-recent?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFlowClosedError(self, deviceId):
        """
        Get Appqoe flow closed error from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/flow-closed-error?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getServiceControllers(self, deviceId):
        """
        Get Appqoe service controllers from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/service-controllers?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatus(self, deviceId):
        """
        Get Appqoe status from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/appqoe/status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Cexp(object):
    """
    Real-Time Monitoring - CloudExpress API
    
    Implements GET POST DEL PUT methods for CloudExpress endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def createApplicationsDetailList(self, vpnId, application, query):
        """
        Get list of cloudexpress applications from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		application	 (string):	Application
		query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cloudx/application/detail?vpnId={vpnId}&application={application}&query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createApplicationsList(self, vpnId, application, query):
        """
        Get list of cloudexpress applications from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		application	 (string):	Application
		query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cloudx/applications?vpnId={vpnId}&application={application}&query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createGatewayExitsList(self, vpnId, application, deviceId):
        """
        Get list of cloudexpress gateway exits from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		application	 (string):	Application
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cloudx/gatewayexits?vpnId={vpnId}&application={application}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createLbApplicationsList(self, vpnId, application, query):
        """
        Get list of cloudexpress load balance applications from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		application	 (string):	Application
		query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cloudx/loadbalance?vpnId={vpnId}&application={application}&query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createLocalExitsList(self, vpnId, application, deviceId):
        """
        Get list of cloudexpress local exits from device (Real Time)
        
        Parameters:
        vpnId	 (string):	VPN Id
		application	 (string):	Application
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cloudx/localexits?vpnId={vpnId}&application={application}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Package(object):
    """
    Configuration - Device Software Package API
    
    Implements GET POST DEL PUT methods for DeviceSoftwarePackage endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getFileContents(self, uuid):
        """
        Get bootstrap file contents
        
        Parameters:
        uuid	 (string):	File uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/custom/file/{uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editConfigFile(self, bootstrapfile, uuid):
        """
        Edit bootstrap file
        
        Parameters:
        bootstrapfile:	Bootstrap file
		uuid	 (string):	File uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/custom/file/{uuid}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, bootstrapfile)
        return response


    def uploadImageFile(self, type):
        """
        Upload virtual image/bootstrap file
        
        Parameters:
        type	 (string):	Upload file type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/custom/uploads/{type}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def createVnfPackage(self, custompackage):
        """
        Create VNF custom package
        
        Parameters:
        custompackage:	Custom package
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/package/custom/vnfPackage"
        response = self.client.apiCall(HttpMethods.POST, endpoint, custompackage)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class OMP(object):
    """
    Real-Time Monitoring - OMP API
    
    Implements GET POST DEL PUT methods for OMP endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getCloudXRecv(self, deviceId):
        """
        Get CloudExpress routes received list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/cloudx?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLinkList(self, state):
        """
        Get OMP connection list
        
        Parameters:
        state	 (string):	Connection state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/links?state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMcastAdvt(self, deviceId):
        """
        Get OMP multicast autodiscover advertised list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/mcastautodiscoveradvt?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMcastRecv(self, deviceId):
        """
        Get OMP multicast autodiscover received list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/mcastautodiscoverrecv?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMcastRoutesAdvt(self, deviceId):
        """
        Get OMP multicast routes advertised list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/mcastroutesadvt?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMcastRoutesRecv(self, deviceId):
        """
        Get OMP multicast routes received list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/mcastroutesrecv?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSessionList(self, deviceId):
        """
        Get OMP session list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/peers?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAdvRoutesList(self, deviceId):
        """
        Get OMP advertised routes list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/routes/advertised?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAdvRoutesListV6(self, deviceId):
        """
        Get OMP advertised routes list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/routes/advertised/ompIpv6?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRcvdRouteList(self, deviceId):
        """
        Get OMP received routes list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/routes/received?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRcvdRouteListVv6(self, deviceId):
        """
        Get OMP received routes list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/routes/received/ompIpv6?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getServices(self, deviceId):
        """
        Get OMP services list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/services?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceStatus(self):
        """
        Get device OMP status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSummary(self, deviceId):
        """
        Get OMP summary
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncSessionList(self, deviceId):
        """
        Get OP session list
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/synced/peers?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAdvTlocsList(self, deviceId):
        """
        Get advertised TLOCs list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/tlocs/advertised?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRcvdTlocsList(self, deviceId):
        """
        Get received TLOCs list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/omp/tlocs/received?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Voice(object):
    """
    Real-Time Monitoring - Voice API
    
    Implements GET POST DEL PUT methods for Voice endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getDspActive(self, deviceId):
        """
        Get DSPFarm Active DSP info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voice/dspActive?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPhoneInfo(self, deviceId):
        """
        Get phone registration info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voice/phoneInfo?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDSPFarmProfiles(self, deviceId):
        """
        Get DSPFarm Profiles info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voice/profiles?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSccpCcmGroups(self, deviceId):
        """
        Get DSPFarm SCCP CCM Groups info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voice/sccpCcmGroups?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSccpConnections(self, deviceId):
        """
        Get DSPFarm SCCP Connections info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voice/sccpConnections?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVoiceCalls(self, deviceId):
        """
        Get voice call info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voice/voiceCalls?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVoipCalls(self, deviceId):
        """
        Get VOIP call info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voice/voipCalls?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIsdnStatus(self, deviceId):
        """
        Retrieve Voice ISDN Status from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voiceisdninfo/isdnstatus?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getControllerInfo(self, deviceId):
        """
        Retrieve T1E1 controller last 15 min stats from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voicet1e1controllerinfo/current15minstats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getControllerStats(self, deviceId):
        """
        Retrieve T1E1 controller total stats from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/voicet1e1controllerinfo/totalstats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Azure(object):
    """
    Configuration - Azure Connect API
    
    Implements GET POST DEL PUT methods for AzureConnect endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getCortexStatus(self):
        """
        Get Cortex List
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def authAzureCredAndAdd(self, credential):
        """
        Authenticate Cloud Account Credentials
        
        Parameters:
        credential:	Credential
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex/cloud/authenticate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, credential)
        return response


    def getMappedWanRG(self, accountid, cloudregion):
        """
        Get Mapped WAN Resource Groups
        
        Parameters:
        accountid	 (string):	Account Id
		cloudregion	 (string):	Cloud region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex/map?accountid={accountid}&cloudregion={cloudregion}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def syncWanRG(self, wanRG):
        """
        Sync WAN Resource Groups
        
        Parameters:
        wanRG:	WAN resource group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex/sync"
        response = self.client.apiCall(HttpMethods.POST, endpoint, wanRG)
        return response


    def getWanRG(self, accountid):
        """
        Get WAN Resource Groups
        
        Parameters:
        accountid	 (string):	Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex/wanrg?accountid={accountid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editWanRG(self, wanRG):
        """
        Edit WAN Resource Groups
        
        Parameters:
        wanRG:	WAN resource group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex/wanrg"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, wanRG)
        return response


    def saveWanRG(self, wanRG):
        """
        Create WAN Resource Groups
        
        Parameters:
        wanRG:	WAN resource group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex/wanrg"
        response = self.client.apiCall(HttpMethods.POST, endpoint, wanRG)
        return response


    def deleteWanRG(self, wanRG):
        """
        Delete WAN Resource Groups
        
        Parameters:
        wanRG:	WAN resource group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cortex/wanrg"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, wanRG)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Network(object):
    """
    Device - Network API
    
    Implements GET POST DEL PUT methods for Network endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getVmanageControlStatus(self, isCached, vpnId):
        """
        Retrieve vManage control status
        
        Parameters:
        isCached	 (boolean):	Is cached flag
		vpnId	 (array):	VPN Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/network/connectionssummary?isCached={isCached}&vpnId={vpnId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRebootCount(self, isCached):
        """
        Retrieve reboot count
        
        Parameters:
        isCached	 (boolean):	Is cached flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/network/issues/rebootcount?isCached={isCached}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNetworkIssuesSummary(self):
        """
        Retrieve network issues summary
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/network/issues/summary"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNetworkStatusSummary(self):
        """
        Retrieve network status summary
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/network/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


